==> tw-server-5.2.4-DEMO-20240918.122110-1-sources.jar: com/elitesland/tw/tw5/server/common/GenerateSeqNumConstants.java <==
package com.elitesland.tw.tw5.server.common;

/**
 * 发号器常量
 */
public class GenerateSeqNumConstants {

    /**
     * 采购合同编号
     */
    public final static String PURCHASE_CONTRACT_NO = "PURCHASE_CONTRACT_NO";

    /**
     * 业务伙伴编号
     */
    public final static String BUSINESS_PARTNER = "BUSINESS_PARTNER";

    /**
     * 采购协议编号
     */
    public final static String PURCHASE_AGREEMENT_NO = "PURCHASE_AGREEMENT_NO";

    /**
     * 报销单号
     */
    public final static String ACC_REIM_NO = "ACC_REIM_NO";

    /**
     * 财务审批记账付款批次编号
     */
    public final static String ACC_PAY_BATCH_CODE = "ACC_PAY_BATCH_CODE";


    /**
     * 付款申请单编号
     */
    public final static String PURCHASE_PAYMENT_NO = "PURCHASE_PAYMENT_NO";

    /**
     * 付款流水号
     */
    public final static String PAY_SERIAL_NUM = "PAY_SERIAL_NUM";

    /**
     * 银企直连批次号
     */
    public final static String BTHNBR = "BTHNBR";
    /**
     * 内部推荐编号
     */
    public final static String INTEEIOR_RECOMMEND_NO = "INTEEIOR_RECOMMEND_NO";
    /**
     * 内部我的推荐编号
     */
    public final static String MY_RECOMMEND_NO = "MY_RECOMMEND_NO";
    // 服务器申请单据编号
    public final static String SERVER_APPLY_NO = "SERVER_APPLY_NO";

    /**
     * 资源编号
     */
    public final static String EMPLOYEE_NO = "EMPLOYEE_NO";

    /**
     * 资金划款编号
     */
    public final static String MONEY_TRANSFER = "MONEY_TRANSFER";
    /**
     * 请假申请编号
     */
    public final static String VACATION_APPLY_NO = "VACATION_APPLY_NO";

    /**
     * 借款申请编号
     */
    public final static String BORROW_MONEY_NO = "BORROW_MONEY_NO";


    /**
     * 结算申请编号
     */
    public final static String SETTLE_APPLY = "SETTLE_APPLY";
}

==> tw-server-5.4.13-DEMO-20241115.014521-1-sources.jar: com/elitesland/tw/tw5/server/common/GenerateSeqNumConstants.java <==
package com.elitesland.tw.tw5.server.common;

/**
 * 发号器常量
 */
public class GenerateSeqNumConstants {

    /**
     * 采购合同编号
     */
    public final static String PURCHASE_CONTRACT_NO = "PURCHASE_CONTRACT_NO";

    /**
     * 业务伙伴编号
     */
    public final static String BUSINESS_PARTNER = "BUSINESS_PARTNER";

    /**
     * 采购协议编号
     */
    public final static String PURCHASE_AGREEMENT_NO = "PURCHASE_AGREEMENT_NO";

    /**
     * 报销单号
     */
    public final static String ACC_REIM_NO = "ACC_REIM_NO";

    /**
     * 财务审批记账付款批次编号
     */
    public final static String ACC_PAY_BATCH_CODE = "ACC_PAY_BATCH_CODE";


    /**
     * 付款申请单编号
     */
    public final static String PURCHASE_PAYMENT_NO = "PURCHASE_PAYMENT_NO";

    /**
     * 付款流水号
     */
    public final static String PAY_SERIAL_NUM = "PAY_SERIAL_NUM";

    /**
     * 银企直连批次号
     */
    public final static String BTHNBR = "BTHNBR";
    /**
     * 内部推荐编号
     */
    public final static String INTEEIOR_RECOMMEND_NO = "INTEEIOR_RECOMMEND_NO";
    /**
     * 内部我的推荐编号
     */
    public final static String MY_RECOMMEND_NO = "MY_RECOMMEND_NO";
    // 服务器申请单据编号
    public final static String SERVER_APPLY_NO = "SERVER_APPLY_NO";

    /**
     * 资源编号
     */
    public final static String EMPLOYEE_NO = "EMPLOYEE_NO";

    /**
     * 资金划款编号
     */
    public final static String MONEY_TRANSFER = "MONEY_TRANSFER";
    /**
     * 请假申请编号
     */
    public final static String VACATION_APPLY_NO = "VACATION_APPLY_NO";

    /**
     * 借款申请编号
     */
    public final static String BORROW_MONEY_NO = "BORROW_MONEY_NO";


    /**
     * 结算申请编号
     */
    public final static String SETTLE_APPLY = "SETTLE_APPLY";

    /**
     * 任务编号
     */
    public final static String PMS_TASK = "PMS_TASK";

    public final static String STATE_FLOW_NO = "STATE_FLOW_NO";

    /**
     * 任务编号
     */
    public final static String PMS_TASK_PRO = "PMS_TASK_PRO";

}
